@@ -1,4 +1,5 @@
 import copy
+from laboro.crypto import Crypto
 from laboro.context.store import Store
 from laboro.logic.processor import Processor
 
@@ -34,6 +35,7 @@ class Context:
     self.parent = None
     self.workspace = None
     self.module_mgr = None
+    self.crypto = Crypto()
     self._store = Store()
 
   def exit(self, kind, value):
